@@ -28,6 +28,8 @@ class PubSub(object):
             kafka_replication_factor=1,
             kafka_partitions=1,
             kafka_poll_timeout=500,
+            kafka_emit_prefix='',
+            kafka_receive_prefix='',
     ):
         self.connection = None
         self.pubsub = None
@@ -47,6 +49,8 @@ class PubSub(object):
             self.kafka_replication_factor = kafka_replication_factor
             self.kafka_partitions = kafka_partitions
             self.kafka_poll_timeout = kafka_poll_timeout
+            self.kafka_emit_prefix = kafka_emit_prefix
+            self.kafka_receive_prefix = kafka_receive_prefix
             self._kafka_producer = None
             self._kafka_consumer = None
             self.create_kafka_topics()
@@ -98,33 +102,35 @@ class PubSub(object):
 
         new_topic_list = list()
         for topic in self.kafka_topics:
-            if topic not in already_topics:
-                new_topic_list.append(NewTopic(
-                    name=topic,
-                    num_partitions=self.kafka_partitions,
-                    replication_factor=self.kafka_replication_factor,
-                ))
-                logger.info("Creating new kafka topic %s" % (topic, ))
+            for topic_prefix in self.kafka_receive_prefix:
+                custom_topic = "%s%s" % (topic_prefix, topic)
+                if custom_topic not in already_topics:
+                    new_topic_list.append(NewTopic(
+                        name=topic,
+                        num_partitions=self.kafka_partitions,
+                        replication_factor=self.kafka_replication_factor,
+                    ))
+                    logger.info("Creating new kafka topic %s" % (topic, ))
 
         kafka_admin.create_topics(new_topic_list)
 
     def emit(self, event, message, emit=False):
-
+        formatted_event = "%s%s" % (self.kafka_emit_prefix, event)
         # Convert dict to string
         message_str = json.dumps(message)
-        logger.debug(" [x] Sent %r:%r" % (event, message_str))
+        logger.debug(" [x] Sent %r:%r" % (formatted_event, message_str))
 
         if not emit:
             return
 
         self.connection = redis.StrictRedis(host=self.host, port=self.port, db=self.database)
         self.pubsub = self.connection.pubsub()
-        self.connection.publish(channel=event, message=message_str)
+        self.connection.publish(channel=formatted_event, message=message_str)
         self.pubsub.close()
 
         if self.enable_kafka:
             kafka_producer = self.get_kafka_producer()
-            future = kafka_producer.send(event, message_str.encode("utf-8"))
+            future = kafka_producer.send(formatted_event, message_str.encode("utf-8"))
             # Should we wait and make sure it is sent ?
             future.get(timeout=60)
 
@@ -137,8 +143,13 @@ class PubSub(object):
             self.receive_redis(listeners, restart_connections)
 
     def receive_kafka(self, listeners):
+        new_listeners = dict()
+        for k, v in listeners.items():
+            for prefix in self.kafka_receive_prefix:
+                new_listeners["%s%s" % (prefix, k)] = v
+
         consumer = self.get_kafka_consumer()
-        consumer.subscribe(listeners.keys())
+        consumer.subscribe(list(new_listeners.keys()))
         while True:
             # poll accepts timeout_ms and it will keep polling new records and batching them until timeout is met
             message = consumer.poll(self.kafka_poll_timeout)
@@ -150,20 +161,23 @@ class PubSub(object):
                 # we get back a dict with batches of records grouped by topic & partition
                 for record in consumer_records:
                     # we might be able to use another type of serializer here that is more efficient.
-                    message_json = json.loads(record.value.decode("utf-8"))
-                    functions = listeners.get(topic_partition.topic)
+                    try:
+                        message_json = json.loads(record.value.decode("utf-8"))
+                        functions = new_listeners.get(topic_partition.topic)
+
+                        if functions:
+                            if not isinstance(functions, list):
+                                logger.info("should be a list of functions but it is not, skipping")
+                            else:
+                                for f in functions:
+                                    f(message_json)
 
-                    if functions:
-                        if not isinstance(functions, list):
-                            logger.info("should be a list of functions but it is not, skipping")
                         else:
-                            for f in functions:
-                                f(message_json)
-
-                    else:
-                        logger.info(
-                            "unable to find function %s in order to consume that topic" % (topic_partition.topic,)
-                        )
+                            logger.info(
+                                "unable to find function %s in order to consume that topic" % (topic_partition.topic,)
+                            )
+                    except Exception as e:
+                        logger.error(str(e))
 
             # This will block until it receives ack., should we block?
             consumer.commit()
